'''
PyTDL - validate ETSI TDL, with Python

Released under Eclipse Public License v1
'''

import argparse
import os

from textx.metamodel import metamodel_from_file
from textx.exceptions import TextXSemanticError, TextXSyntaxError
import pytdl_lib as lib

DIR = os.path.dirname(os.path.abspath(__file__))

try:
    TDL_MM = metamodel_from_file(DIR+'/../tdl_grammars/TDLan2.tx',
        classes=[
            lib.Package, 
            lib.TestDescription, 
            lib.BehaviourDescription,
            lib.CompoundBehaviour,
            lib.Block,
            lib.Message]
    )
except TextXSemanticError as err:
    print "Error in TDL grammar files:"
    print err
    print "Quitting."
    exit(-1)

PARSER = argparse.ArgumentParser(description='TDL python utilities.')
PARSER.add_argument('command', nargs=1, help='the command to be executed')
PARSER.add_argument('filename', nargs=1, help='the TDL script to manipulate')

ARGS = PARSER.parse_args()

FN = ARGS.filename[0]
CMD = ARGS.command[0]

P = None
try:
    P = TDL_MM.model_from_file(FN)
except TextXSyntaxError as err:
    print "Syntax error found in file " + FN + ":"
    print ""
    print "\t" + str(err)
    print ""
    print "Quitting."
    exit(-2)

if CMD == "validate":
    exit(0)

if CMD == "python":
    print "import pytdl.interpreter"
    print ""

    P.to_python()
    exit(0)

print "###################"
print "Tests in the package:"

lib.list_test_descriptions(P)

print "###################"
print "Everything in the package:"

for i in P.packagedElement:
    print i.name
